@@ -1,10 +1,10 @@
-use ::syntax::ast::{MetaItem, MetaItem_};
+use ::syntax::ast::{MetaItem, MetaItemKind};
 use ::syntax::codemap::{Spanned};
 use syntax::attr::AttrMetaMethods;
 
 pub fn get_meta_item_value(meta_item: &MetaItem, name: &str) -> Option<String> {
     match meta_item {
-        &Spanned { node: MetaItem_::MetaList(_, ref items), span: _ } => {
+        &Spanned { node: MetaItemKind::List(_, ref items), span: _ } => {
             for ref item in items {
                 if item.name() == name {
                     match item.value_str() {
